summaryrefslogtreecommitdiff
path: root/FS/FS/Template_Mixin.pm
diff options
context:
space:
mode:
authorMitch Jackson <mitch@freeside.biz>2018-05-19 19:51:03 -0500
committerMitch Jackson <mitch@freeside.biz>2018-05-19 19:51:03 -0500
commitc34212f6b04a6796467ad1fb5d32154eae1ea40d (patch)
tree6141b0c7451d0b159c41c814652f89ed456ffb52 /FS/FS/Template_Mixin.pm
parent709a481dd9a9f29009505356603db66613bf2cb6 (diff)
RT# 78190 Fix bill summary missing taxes or fees
Diffstat (limited to 'FS/FS/Template_Mixin.pm')
-rw-r--r--FS/FS/Template_Mixin.pm11
1 files changed, 5 insertions, 6 deletions
diff --git a/FS/FS/Template_Mixin.pm b/FS/FS/Template_Mixin.pm
index 51f89f7..c90e652 100644
--- a/FS/FS/Template_Mixin.pm
+++ b/FS/FS/Template_Mixin.pm
@@ -1417,13 +1417,12 @@ sub print_generic {
$tax_section->{'description'} = $self->mt($tax_description);
$tax_section->{'summarized'} = '';
- if ( !grep $tax_section, @sections ) {
+ # append tax section unless it's already there
+ push @sections, $tax_section
+ unless grep {$_ eq $tax_section} @sections;
- # append it if it's not already there
- push @sections, $tax_section;
- push @summary_subtotals, $tax_section;
-
- }
+ push @summary_subtotals, $tax_section
+ unless grep {$_ eq $tax_section} @summary_subtotals;
}
} else {